@@ -41,8 +41,8 @@ MH_DYLINKER_SYM = "_mh_dylinker_header"
 
 (
     MH_OBJECT, MH_EXECUTE, MH_FVMLIB, MH_CORE, MH_PRELOAD, MH_DYLIB,
-    MH_DYLINKER, MH_BUNDLE, MH_DYLIB_STUB,
-) = range(0x1, 0xa)
+    MH_DYLINKER, MH_BUNDLE, MH_DYLIB_STUB, MH_DSYM
+) = range(0x1, 0xb)
 
 (
     MH_NOUNDEFS, MH_INCRLINK, MH_DYLDLINK, MH_BINDATLOAD, MH_PREBOUND,
@@ -69,6 +69,7 @@ MH_FILETYPE_NAMES = {
     MH_DYLINKER:    'dynamic link editor',
     MH_BUNDLE:      'dynamically bound bundle',
     MH_DYLIB_STUB:  'shared library stub for static linking',
+    MH_DSYM:        'symbol information',
 }
 
 MH_FILETYPE_SHORTNAMES = {
@@ -81,6 +82,7 @@ MH_FILETYPE_SHORTNAMES = {
     MH_DYLINKER:    'dylinker',
     MH_BUNDLE:      'bundle',
     MH_DYLIB_STUB:  'dylib_stub',
+    MH_DSYM:        'dsym',
 }
 
 MH_FLAGS_NAMES = {
@@ -147,9 +149,9 @@ class mach_header_64(mach_header):
 
 class load_command(Structure):
     _fields_ = (
-    ('cmd', p_ulong),
-    ('cmdsize', p_ulong),
-)
+        ('cmd', p_ulong),
+        ('cmdsize', p_ulong),
+    )
 
 LC_REQ_DYLD = 0x80000000L
 
@@ -165,6 +167,11 @@ LC_LOAD_WEAK_DYLIB = LC_REQ_DYLD | 0x18
 
 LC_SEGMENT_64 = 0x19
 LC_ROUTINES_64 = 0x1a
+LC_UUID = 0x1b
+LC_RPATH = (0x1c | LC_REQ_DYLD)
+LC_CODE_SIGNATURE = 0x1d
+LC_CODE_SEGMENT_SPLIT_INFO = 0x1e
+LC_REEXPORT_DYLIB = 0x1f | LC_REQ_DYLD
 
 # this is really a union.. but whatever
 class lc_str(p_ulong):
@@ -483,6 +490,23 @@ class fvmfile_command(Structure):
         ('header_addr', p_ulong),
     )
 
+class uuid_command (Structure):
+    _fields_ = (
+        ('uuid', p_str16),
+    )
+
+class rpath_command (Structure):
+    _fields_ = (
+        ('path', lc_str),
+    )
+
+class linkedit_data_command (Structure):
+    _fields_ = (
+        ('dataoff',   p_ulong),
+        ('datassize', p_ulong),
+    )
+
+
 LC_REGISTRY = {
     LC_SEGMENT:         segment_command,
     LC_IDFVMLIB:        fvmlib_command,
@@ -509,6 +533,11 @@ LC_REGISTRY = {
     LC_FVMFILE:         fvmfile_command,
     LC_SEGMENT_64:      segment_command_64,
     LC_ROUTINES_64:     routines_command_64,
+    LC_UUID:            uuid_command,
+    LC_RPATH:           rpath_command,
+    LC_CODE_SIGNATURE:  linkedit_data_command,
+    LC_CODE_SEGMENT_SPLIT_INFO:  linkedit_data_command,
+    LC_REEXPORT_DYLIB:  dylib_command,
 }
 
 class nlist(Structure):
